@@ -304,7 +304,7 @@ def drawMultiLine(
     stroke_color: color of stroke
     space: add more space between each line of text
     """
-
+    print('This method will be deprecated, use drawMultiline instead')
     values = getMultipleSize(phrase_wrapped, font)
     height, _, spaces = values[1], values[2], values[3]
 
@@ -332,6 +332,28 @@ def drawMultiLine(
         return draw
 
 
+def drawMultiline(x, y, draw, text, font, color, anchor='la', spacing=0, align='left'):
+    """
+    Draws multiple line of text
+    x : int coordinate
+    y : int coordinate
+    draw : ImageDraw object
+    text : str with \n or list[str]
+    font : ImageFont object
+    anchor : str
+        - #https://pillow.readthedocs.io/en/stable/handbook/text-anchors.html#text-anchors
+        - reference to this for anchor points
+        - avoid top, use ascent, broken because Pillow????
+    spacing : int space between text
+    align : str (left, center, right)
+
+    return ImageDraw object
+    """
+    if type(text) in [list, tuple]:
+        text = "\n".join(text)
+    return draw.multiline_text((x,y), text, fill=color, font=font, anchor=anchor, spacing=spacing, align=align)
+
+
 def fitSize(fontPath, message, canvasW):
     """
     return (int) optimal size of font inside a canvas
@@ -373,6 +395,49 @@ def fitFontInCanvas(fontPath, message, WH):
 
     return fontDefiner(fontPath, size)
 
+def wrapToCanvas(text, width, font):
+    text = [each + ' ' for each in text.split(' ')]
+    total = []
+    i = 0
+    while i <= len(text):
+        if getSize("".join(text[:i]), font)[0] > width:
+            total.append("".join(text[:i-1]).strip(' '))
+            text = text[i:]
+            i = 0
+        i += 1
+    if len(text) > 0:
+        if getSize(total[-1]+' '+"".join(text).strip(' '), font)[0] < width:
+            total[-1] = total[-1]+' '+"".join(text).strip(' ')
+        else:
+            total.append("".join(text).strip(' '))
+    return total
+""" 
+def wrapToCanvas(text, width, font):
+    try:
+        i = 0 
+        total = []
+        while True:
+            j = i
+            while text[i+1] not in ['\n', ' '] or i+2==len(text):
+                i += 1
+            if getSize(text[:i+1], font)[0] >= width:
+                total.append(text[:j+1].strip(' '))
+                text = text[j+1:]
+                i = 0
+                j = 0
+            else:
+                i += 1
+            if i+2 == len(text):
+                total.append(text.strip(' '))
+
+    except:
+        total.append(text[:j+1].strip(' '))
+        total.append(text[j+1:i+1])
+    
+    return total
+
+"""
+
 
 def getSize(text_string, font):
     """
@@ -388,13 +453,26 @@ def getSize(text_string, font):
     text_width = font.getmask(text_string).getbbox()[2]
     text_height = font.getmask(text_string).getbbox()[3] - ascent - descent
     """
-    ascent, descent = font.getmetrics()
     text_width, text_height = font.getsize(text_string)
 
     #return (text_width, text_height-descent)
     return (text_width, text_height)
 
 
+def getSizeMultiline(text, font, spacing=0):
+    """
+    Get sizes of a multiline text
+    Substitute to getMultipleSize
+
+    text : str with \n or list[str]
+    font : ImageFont
+
+    return width, height
+    """
+    if type(text) in [list, tuple]:
+        text = "\n".join(text)
+    return font.getsize_multiline(text=text, spacing=spacing)
+
 
 def getMultipleSize(text_wrapped, font):
     """
@@ -405,6 +483,7 @@ def getMultipleSize(text_wrapped, font):
     return max_width, max_height of one line,
     total max_height, total spaces
     """
+    print('This method will be deprecated, use getSizeMultiline instead')
 
     max_width, max_height = 0, 0
     for i in range(len(text_wrapped)):
@@ -417,8 +496,10 @@ def getMultipleSize(text_wrapped, font):
         if height > max_height:
             max_height = height
 
-    spaces = int(max_height / 4)
-    max_single_height = max_height
+    ascent, descent = font.getmetrics()
+    spaces = descent + ascent
+    max_single_height = getSize('M', font)[1]
+    #max_single_height = max_height
     max_height = max_height * len(text_wrapped) + spaces * (len(text_wrapped) - 1)
 
     return max_width, max_single_height, max_height, spaces
@@ -514,10 +595,10 @@ def blurImage(image, radius):
     radius: quantity of blur
     """
     image = image.filter(ImageFilter.GaussianBlur(radius=radius))
-    return image
+    return image, ImageDraw.Draw(image)
 
 
-def roundCorners(im, rad):
+def roundCorners(image, rad):
     """
     Rounds the corners of an image to given radius
     im: Image object
@@ -525,6 +606,9 @@ def roundCorners(im, rad):
 
     return Image
     """
+    sampling = 4
+    rad*=sampling
+    im = image.copy().resize((each*sampling for each in image.size))
     mask = Image.new("L", im.size)
     if rad > min(*im.size) // 2:
         rad = min(*im.size) // 2
@@ -539,11 +623,10 @@ def roundCorners(im, rad):
     draw.rectangle([rad, 0, im.width - rad, im.height], fill=255)
     draw.rectangle([0, rad, im.width, im.height - rad], fill=255)
     
-    mask,_ = superSample(mask, 8)
-    im.putalpha(mask)
-    
+    mask = mask.resize(image.size, resample=Image.ANTIALIAS)
+    image.putalpha(mask)
 
-    return im
+    return image
 
 
 def roundCornersAngles(im, rad, angles):
@@ -1108,3 +1191,5 @@ def roundCorners(im, rad):
     return im
 
     """
+
+
